@@ -5,5 +5,6 @@ from .task_datastore import TaskDataStore
 
 from .local_storage import LocalStorage
 from .s3_storage import S3Storage
+from .azure_storage import AzureStorage
 
-DATASTORES = {"local": LocalStorage, "s3": S3Storage}
+DATASTORES = {"local": LocalStorage, "s3": S3Storage, "azure": AzureStorage}
