@@ -1,4 +1,4 @@
-import click
+from metaflow._vendor import click
 import os
 import sys
 import time
@@ -11,7 +11,7 @@ from metaflow import R
 from metaflow.exception import CommandException, METAFLOW_EXIT_DISALLOW_RETRY
 from metaflow.metadata.util import sync_local_metadata_from_datastore
 from metaflow.metaflow_config import DATASTORE_LOCAL_DIR
-from metaflow.mflog import TASK_LOG_SOURCE, capture_output_to_mflog
+from metaflow.mflog import TASK_LOG_SOURCE
 
 from .batch import Batch, BatchKilledException
 
