@@ -386,20 +386,25 @@ class BatchJob(object):
             )
         if "resourceRequirements" not in self.payload["containerOverrides"]:
             self.payload["containerOverrides"]["resourceRequirements"] = []
+
+        # %g will format the value without .0 if it doesn't have a fractional part
+        #
+        # While AWS Batch supports fractional values for fargate, it does not
+        # seem to like seeing values like 2.0 for non-fargate environments.
         self.payload["containerOverrides"]["resourceRequirements"].append(
-            {"value": str(cpu), "type": "VCPU"}
+            {"value": "%g" % (float(cpu)), "type": "VCPU"}
         )
         return self
 
     def memory(self, mem):
-        if not (isinstance(mem, (int, unicode, basestring)) and int(mem) > 0):
+        if not (isinstance(mem, (int, unicode, basestring, float)) and float(mem) > 0):
             raise BatchJobException(
                 "Invalid memory value ({}); it should be greater than 0".format(mem)
             )
         if "resourceRequirements" not in self.payload["containerOverrides"]:
             self.payload["containerOverrides"]["resourceRequirements"] = []
         self.payload["containerOverrides"]["resourceRequirements"].append(
-            {"value": str(mem), "type": "MEMORY"}
+            {"value": str(int(float(mem))), "type": "MEMORY"}
         )
         return self
 
@@ -408,15 +413,20 @@ class BatchJob(object):
             raise BatchJobException(
                 "invalid gpu value: ({}) (should be 0 or greater)".format(gpu)
             )
-        if int(gpu) > 0:
+        if float(gpu) > 0:
             if "resourceRequirements" not in self.payload["containerOverrides"]:
                 self.payload["containerOverrides"]["resourceRequirements"] = []
+
+            # Only integer values are supported but the value passed to us
+            # could be a float-converted-to-string
             self.payload["containerOverrides"]["resourceRequirements"].append(
-                {"type": "GPU", "value": str(gpu)}
+                {"type": "GPU", "value": str(int(float(gpu)))}
             )
         return self
 
     def environment_variable(self, name, value):
+        if value is None:
+            return self
         if "environment" not in self.payload["containerOverrides"]:
             self.payload["containerOverrides"]["environment"] = []
         value = str(value)
