@@ -20,7 +20,7 @@ from metaflow.metaflow_config import (
     ECS_FARGATE_EXECUTION_ROLE,
     DATASTORE_LOCAL_DIR,
 )
-from metaflow.sidecar import SidecarSubProcess
+from metaflow.sidecar import Sidecar
 from metaflow.unbounded_foreach import UBF_CONTROL
 
 from .batch import BatchException
@@ -29,55 +29,42 @@ from ..aws_utils import compute_resource_attributes, get_docker_registry
 
 class BatchDecorator(StepDecorator):
     """
-    Step decorator to specify that this step should execute on AWS Batch.
+    Specifies that this step should execute on [AWS Batch](https://aws.amazon.com/batch/).
 
-    This decorator indicates that your step should execute on AWS Batch. Note
-    that you can apply this decorator automatically to all steps using the
-    ```--with batch``` argument when calling run/resume. Step level decorators
-    within the code are overrides and will force a step to execute on AWS Batch
-    regardless of the ```--with``` specification.
-
-    To use, annotate your step as follows:
-    ```
-    @batch
-    @step
-    def my_step(self):
-        ...
-    ```
     Parameters
     ----------
     cpu : int
-        Number of CPUs required for this step. Defaults to 1. If @resources is
-        also present, the maximum value from all decorators is used
+        Number of CPUs required for this step. Defaults to 1. If `@resources` is
+        also present, the maximum value from all decorators is used.
     gpu : int
-        Number of GPUs required for this step. Defaults to 0. If @resources is
-        also present, the maximum value from all decorators is used
+        Number of GPUs required for this step. Defaults to 0. If `@resources` is
+        also present, the maximum value from all decorators is used.
     memory : int
-        Memory size (in MB) required for this step. Defaults to 4096. If
-        @resources is also present, the maximum value from all decorators is
-        used
+        Memory size (in MB) required for this step. Defaults to 4096 (4GB). If
+        `@resources` is also present, the maximum value from all decorators is
+        used.
     image : string
         Docker image to use when launching on AWS Batch. If not specified, a
-        default docker image mapping to the current version of Python is used
+        default Docker image mapping to the current version of Python is used.
     queue : string
         AWS Batch Job Queue to submit the job to. Defaults to the one
-        specified by the environment variable METAFLOW_BATCH_JOB_QUEUE
+        specified by the configuration variable `METAFLOW_BATCH_JOB_QUEUE`.
     iam_role : string
-        AWS IAM role that AWS Batch container uses to access AWS cloud resources
-        (Amazon S3, Amazon DynamoDb, etc). Defaults to the one specified by the
-        environment variable METAFLOW_ECS_S3_ACCESS_IAM_ROLE
+        AWS IAM role that AWS Batch container uses to access AWS cloud resources.
+        Defaults to the one specified by the configuration variable `METAFLOW_ECS_S3_ACCESS_IAM_ROLE`.
     execution_role : string
-        AWS IAM role that AWS Batch can use to trigger AWS Fargate tasks.
-        Defaults to the one determined by the environment variable
-        METAFLOW_ECS_FARGATE_EXECUTION_ROLE https://docs.aws.amazon.com/batch/latest/userguide/execution-IAM-role.html
+        AWS IAM role that AWS Batch can use [to trigger AWS Fargate tasks]
+        (https://docs.aws.amazon.com/batch/latest/userguide/execution-IAM-role.html).
+        Defaults to the one determined by the configuration variable
+        `METAFLOW_ECS_FARGATE_EXECUTION_ROLE`.
     shared_memory : int
         The value for the size (in MiB) of the /dev/shm volume for this step.
-        This parameter maps to the --shm-size option to docker run.
+        This parameter maps to the `--shm-size` option in Docker.
     max_swap : int
         The total amount of swap memory (in MiB) a container can use for this
-        step. This parameter is translated to the --memory-swap option to
-        docker run where the value is the sum of the container memory plus the
-        max_swap value.
+        step. This parameter is translated to the `--memory-swap` option in
+        Docker where the value is the sum of the container memory plus the
+        `max_swap` value.
     swappiness : int
         This allows you to tune memory swappiness behavior for this step.
         A swappiness value of 0 causes swapping not to happen unless absolutely
@@ -250,7 +237,8 @@ class BatchDecorator(StepDecorator):
             # Register book-keeping metadata for debugging.
             metadata.register_metadata(run_id, step_name, task_id, entries)
 
-            self._save_logs_sidecar = SidecarSubProcess("save_logs_periodically")
+            self._save_logs_sidecar = Sidecar("save_logs_periodically")
+            self._save_logs_sidecar.start()
 
         num_parallel = int(os.environ.get("AWS_BATCH_JOB_NUM_NODES", 0))
         if num_parallel >= 1 and ubf_context == UBF_CONTROL:
@@ -289,7 +277,7 @@ class BatchDecorator(StepDecorator):
                 )
 
         try:
-            self._save_logs_sidecar.kill()
+            self._save_logs_sidecar.terminate()
         except:
             # Best effort kill
             pass
